@@ -59,6 +59,17 @@ _get_option_group (AvMetaReader *reader)
 
 	if (! gst_is_initialized ()) {
 		option_group = gst_init_get_option_group ();
+
+		if (NULL == option_group) {
+			/*
+			 * If GStreamer was compiled with
+			 * -Doption-parsing=false (e.g., on OpenWrt), then
+			 *  option_group will be NULL. As a result, the later
+			 *  call to g_option_context_parse will not initialize
+			 *  GStreamer. Initialize here.
+			 */
+			gst_init(NULL, NULL);
+		}
 	}
 
 	return option_group;
