@@ -363,7 +363,24 @@ _return:
 GOptionGroup *
 av_render_gst_get_option_group (AvRender *render)
 {
-	return gst_is_initialized () ? NULL : gst_init_get_option_group ();
+	static GOptionGroup *option_group = NULL;
+
+	if (! gst_is_initialized ()) {
+		option_group = gst_init_get_option_group ();
+
+		if (NULL == option_group) {
+			/*
+			 * If GStreamer was compiled with
+			 * -Doption-parsing=false (e.g., on OpenWrt), then
+			 *  option_group will be NULL. As a result, the later
+			 *  call to g_option_context_parse will not initialize
+			 *  GStreamer. Initialize here.
+			 */
+			gst_init(NULL, NULL);
+		}
+	}
+
+	return option_group;
 }
 
 static void av_render_gst_register_type (GTypeModule *module);
