@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __DMAPD_DMAP_DB_GHASHTABLE
-#define __DMAPD_DMAP_DB_GHASHTABLE
+#ifndef _DMAPD_DMAP_DB_GHASHTABLE_H
+#define _DMAPD_DMAP_DB_GHASHTABLE_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -58,6 +58,6 @@ typedef struct {
 
 GType dmapd_dmap_db_ghashtable_get_type (void);
 
-#endif /* __DMAPD_DMAP_DB_GHASHTABLE */
-
 G_END_DECLS
+
+#endif
