@@ -73,12 +73,6 @@ _set_property (GObject *object,
 			g_free (record->priv->location);
 			record->priv->location = g_value_dup_string (value);
 			break;
-		case PROP_HASH:
-			if (record->priv->hash) {
-				g_array_unref(record->priv->hash);
-			}
-			record->priv->hash = g_value_get_boxed (value);
-			break;
 		case PROP_LARGE_FILESIZE:
 			record->priv->largefilesize = g_value_get_int (value);
 			break;
@@ -114,7 +108,13 @@ _set_property (GObject *object,
 			if (record->priv->thumbnail) {
 				g_array_unref(record->priv->thumbnail);
 			}
-			record->priv->thumbnail = g_value_get_boxed (value);
+			record->priv->thumbnail = g_array_ref(g_value_get_boxed (value));
+			break;
+		case PROP_HASH:
+			if (record->priv->hash) {
+				g_array_unref(record->priv->hash);
+			}
+			record->priv->hash = g_array_ref(g_value_get_boxed (value));
 			break;
 		case PROP_MTIME:
 			record->priv->mtime = g_value_get_int (value);
@@ -138,9 +138,6 @@ _get_property (GObject *object,
 		case PROP_LOCATION:
 			g_value_set_static_string (value, record->priv->location);
 			break;
-		case PROP_HASH:
-			g_value_set_boxed (value, record->priv->hash);
-			break;
 		case PROP_LARGE_FILESIZE:
 			g_value_set_int (value, record->priv->largefilesize);
 			break;
@@ -169,7 +166,10 @@ _get_property (GObject *object,
 			g_value_set_static_string (value, record->priv->comments);
 			break;
 		case PROP_THUMBNAIL:
-			g_value_set_boxed (value, record->priv->thumbnail);
+			g_value_set_boxed (value, g_array_ref(record->priv->thumbnail));
+			break;
+		case PROP_HASH:
+			g_value_set_boxed (value, g_array_ref(record->priv->hash));
 			break;
 		case PROP_MTIME:
 			g_value_set_int (value, record->priv->mtime);
