@@ -70,7 +70,7 @@ _process_record (gpointer id, DmapRecord *record, gpointer user_data)
 	SoupMessage *soup_message;
 	gchar *location = NULL, *desc1 = NULL, *desc2 = NULL;
 
-	if (IS_DMAP_AV_RECORD (record)) {
+	if (DMAP_IS_AV_RECORD (record)) {
 		/* FIXME: print all record properties; need DAAP and DPAP version: */
 		g_object_get (record,
 			     "location",   &location,
@@ -83,7 +83,7 @@ _process_record (gpointer id, DmapRecord *record, gpointer user_data)
 		g_assert (desc2);
 
 		g_print ("%d: %s %s %s\n", GPOINTER_TO_UINT (id), desc1, desc2, location);
-	} else if (IS_DMAP_IMAGE_RECORD (record)) {
+	} else if (DMAP_IS_IMAGE_RECORD (record)) {
 		/* FIXME: print all record properties; need DAAP and DPAP version: */
 		g_object_get (record,
 			     "location", &location,
@@ -125,9 +125,9 @@ _get_service_type (DmapConnection *connection)
 {
 	DmapMdnsServiceType type;
 
-	if (IS_DMAP_AV_CONNECTION (connection)) {
+	if (DMAP_IS_AV_CONNECTION (connection)) {
 		type = DMAP_MDNS_SERVICE_TYPE_DAAP;
-	} else if (IS_DMAP_IMAGE_CONNECTION (connection)) {
+	} else if (DMAP_IS_IMAGE_CONNECTION (connection)) {
 		type = DMAP_MDNS_SERVICE_TYPE_DPAP;
 	} else {
 		g_error ("Bad connection");
