@@ -25,8 +25,8 @@
 #include <stdlib.h>
 #include <libdmapsharing/dmap.h>
 
-#include "dmapd-test-daap-record.h"
-#include "dmapd-test-parse-plugin-option.h"
+#include "db-builder-gdir.h"
+#include "dmapd-daap-record.h"
 #include "util.h"
 
 static void
@@ -58,6 +58,7 @@ main(void)
 	util_stringleton_init ();
 	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, _debug_null, NULL);
 
+	_run_suite (db_test_builder_gdir_suite());
 	_run_suite (dmapd_test_parse_plugin_option_suite());
 	_run_suite (dmapd_test_daap_record_suite());
 
