@@ -232,23 +232,20 @@ _create_share (protocol_id_t protocol,
                DmapContainerDb *container_db,
                share_def_t *share_def)
 {
-	char      *name  = NULL;
 	DmapShare *share = NULL;
 
 	g_debug("Initializing %s share", _protocol_map[protocol]);
 
-	name = share_def->name ? g_strdup(share_def->name) : _default_share_name(protocol);
-
 	switch(protocol) {
 	case DAAP:
-		share = DMAP_SHARE(dmap_av_share_new(name,
+		share = DMAP_SHARE(dmap_av_share_new(share_def->name,
 		                                     share_def->password,
 		                                     db,
 		                                     container_db,
 		                                     share_def->transcode_mimetype));
 		break;
 	case DPAP:
-		share = DMAP_SHARE(dmap_image_share_new(name,
+		share = DMAP_SHARE(dmap_image_share_new(share_def->name,
 		                                        share_def->password,
 		                                        db, container_db,
 		                                        share_def->transcode_mimetype));
@@ -257,8 +254,6 @@ _create_share (protocol_id_t protocol,
 		g_error("Unknown share type");
 	}
 
-	g_free(name);
-
 	return share;
 }
 
@@ -822,12 +817,20 @@ main (int argc, char *argv[])
 	}
 
 	if (NULL != _music_dirs) {
+		if (NULL == _share_name) {
+			_share_name = _default_share_name(DAAP);
+		}
+
 		_add_share(DAAP, _share_name, _password, _music_dirs,
 		           _music_formats, _transcode_mimetype,
 		           _enable_rt_transcode);
 	}
 
 	if (NULL != _picture_dirs) {
+		if (NULL == _share_name) {
+			_share_name = _default_share_name(DPAP);
+		}
+
 		_add_share(DPAP, _share_name, _password, _picture_dirs,
 		           _picture_formats, NULL, FALSE);
 	}
